@@ -7,23 +7,31 @@ import glob
 from doreah.control import mainfunction
 
 @mainfunction({},shield=True)
-def main(packagename):
+def main(packagename,test=False):
 
 	assert os.path.exists(packagename)
 	sys.argv = (sys.argv[0],"sdist","bdist_wheel")
 
 	# use local package!
-	sys.path = ["."] + sys.path
+	sys.path.insert(0,".")
 
-	module = importlib.import_module(packagename)
 	pkginfo = importlib.import_module(".__pkginfo__",package=packagename)
 	pkginfo = pkginfo.__dict__
+	print(pkginfo)
 
 
 	# extract info
 
-	with open("README.md", "r") as fh:
-	    long_description = fh.read()
+	readmelocs = [
+		packagename + "/README.md",
+		"README.md"
+	]
+
+	for rml in readmelocs:
+		if os.path.exists(rml):
+			with open(rml, "r") as fh:
+			    long_description = fh.read()
+			break
 
 	setuptools.setup(
 	    name=pkginfo.get("links",{}).get("pypi") or pkginfo["name"],
@@ -42,22 +50,25 @@ def main(packagename):
 	        "Operating System :: OS Independent",
 	    ],
 		python_requires=">=3.5",
-		install_requires=pkginfo["requires"],
-		package_data={'': pkginfo["resources"]},
+		install_requires=pkginfo.get("requires",[]),
+		package_data={'': pkginfo.get("resources",[])},
 		include_package_data=True,
 		entry_points = {
 			"console_scripts":[
 				cmd + " = " + pkginfo["name"] + "." + pkginfo["commands"][cmd]
-				for cmd in pkginfo["commands"]
-			]
+				for cmd in pkginfo.get("commands",[])
+			],
+			**{k:pkginfo["entrypoints"][k] for k in pkginfo.get("entrypoints",{})}
 		}
 	)
 
 
 	os.system("git tag v" + ".".join(str(n) for n in pkginfo["version"]))
 
-
-	os.system("python3 -m twine upload --skip-existing dist/*")
+	uploadcmd = "python3 -m twine upload --skip-existing dist/*"
+	if test:
+		uploadcmd += " --repository-url https://test.pypi.org/legacy/"
+	os.system(uploadcmd)
 
 	shutil.rmtree("build")
 	shutil.rmtree("dist")
